@@ -3,11 +3,12 @@ package MooX::Cmd::Tester;
 use strict;
 use warnings;
 
-our $VERSION = "0.013";
+our $VERSION = "0.014";
 
 require Exporter;
 use Test::More import => ['!pass'];
 use Package::Stash;
+use Capture::Tiny qw(:all);
 
 use parent qw(Test::Builder::Module Exporter);
 
@@ -66,42 +67,44 @@ sub _run_with_capture
 {
     my ( $app, $argv ) = @_;
 
-    require IO::TieCombine;
-    my $hub = IO::TieCombine->new;
-
-    my $stdout = tie local *STDOUT, $hub, 'stdout';
-    my $stderr = tie local *STDERR, $hub, 'stderr';
-
     my ( $execute_rv, $cmd, $cmd_name );
 
-    my $ok = eval {
-        local $TEST_IN_PROGRESS = 1;
-        local @ARGV             = @$argv;
-
-        my $tb = $CLASS->builder();
-
-        $cmd = ref $app ? $app : $app->new_with_cmd;
-        ref $app and $app = ref $app;
-        my $test_ident = "$app => [ " . join( " ", @$argv ) . " ]";
-        ok( $cmd->isa($app), "got a '$app' from new_with_cmd" );
-        @$argv
-          and defined( $cmd_name = $cmd->command_name )
-          and ok( ( grep { $_ =~ m/$cmd_name/ } @$argv ), "proper cmd name from $test_ident" );
-        ok( scalar @{ $cmd->command_chain } <= 1 + scalar @$argv, "\$#argv vs. command chain length testing $test_ident" );
-        @$argv and ok( $cmd->command_chain_end == $cmd->command_chain->[-1], "command_chain_end ok" );
-
-        unless ( $execute_rv = $cmd->execute_return )
+    my ( $stdout, $stderr, $ok );
+    my ($merged) = tee_merged
+    {
+        ( $stdout, $stderr, $ok ) = tee
         {
-            my ( $command_execute_from_new, $command_execute_method_name );
-            my $cce = $cmd->can("command_chain_end");
-            $cce                      and $cce                      = $cce->($cmd);
-            $cce                      and $command_execute_from_new = $cce->can("command_execute_from_new");
-            $command_execute_from_new and $command_execute_from_new = $command_execute_from_new->($cce);
-            $command_execute_from_new or $command_execute_method_name = $cce->can('command_execute_method_name');
-            $command_execute_method_name
-              and $execute_rv = [ $cce->can( $command_execute_method_name->($cce) )->($cce) ];
+            eval {
+                local $TEST_IN_PROGRESS = 1;
+                local @ARGV             = @$argv;
+
+                my $tb = $CLASS->builder();
+
+                $cmd = ref $app ? $app : $app->new_with_cmd;
+                ref $app and $app = ref $app;
+                my $test_ident = "$app => [ " . join( " ", @$argv ) . " ]";
+                ok( $cmd->isa($app), "got a '$app' from new_with_cmd" );
+                @$argv
+                  and defined( $cmd_name = $cmd->command_name )
+                  and ok( ( grep { $_ =~ m/$cmd_name/ } @$argv ), "proper cmd name from $test_ident" );
+                ok( scalar @{ $cmd->command_chain } <= 1 + scalar @$argv,
+                    "\$#argv vs. command chain length testing $test_ident" );
+                @$argv and ok( $cmd->command_chain_end == $cmd->command_chain->[-1], "command_chain_end ok" );
+
+                unless ( $execute_rv = $cmd->execute_return )
+                {
+                    my ( $command_execute_from_new, $command_execute_method_name );
+                    my $cce = $cmd->can("command_chain_end");
+                    $cce                      and $cce                      = $cce->($cmd);
+                    $cce                      and $command_execute_from_new = $cce->can("command_execute_from_new");
+                    $command_execute_from_new and $command_execute_from_new = $command_execute_from_new->($cce);
+                    $command_execute_from_new or $command_execute_method_name = $cce->can('command_execute_method_name');
+                    $command_execute_method_name
+                      and $execute_rv = [ $cce->can( $command_execute_method_name->($cce) )->($cce) ];
+                }
+                1;
+            }
         }
-        1;
     };
 
     my $error = $ok ? undef : $@;
@@ -109,9 +112,9 @@ sub _run_with_capture
     return {
         app        => $app,
         cmd        => $cmd,
-        stdout     => $hub->slot_contents('stdout'),
-        stderr     => $hub->slot_contents('stderr'),
-        output     => $hub->combined_contents,
+        stdout     => $stdout,
+        stderr     => $stderr,
+        output     => $merged,
         error      => $error,
         execute_rv => $execute_rv,
     };
